==> tmda-0.90.tgz: tmda-0.90/htdocs/links.h <==
<!-- -*- html -*- -->
<h3>About</h3>
<li><a href="index.html">Introduction</a>
<li><a href="history.html">History</a>
<li><a href="features.html">Features</a>
<li><a href="challengeresponse.html">Challenge/Response</a>
<li><a href="results.html">Results &amp; Testimonials</a>
<li><a href="inuse.html">TMDA In Use</a>
<li><a href="press.html">Press Coverage</a>
<li><a href="donations.html">Donations</a>
<h3>Install</h3>
<li><a href="requirements.html">Requirements</a>
<li><a href="download.html">Download</a>
<li><a href="install.html">Installation</a>
<li><a href="upgrade.html">Upgrading</a>
<h3>Configuration</h3>
<li><a href="config.html">Overview</a>
<li><a href="config-pre.html">Pre-Configuration</a>
<li><a href="config-server.html">Server Configuration</a>
<li><a href="config-client.html">Client Configuration</a>
<li><a href="config-vars.html">Configuration Variables</a>
<li><a href="config-filter.html">Filter Specification</a>
<li><a href="filter-sources.html">Filter Sources</a>
<h3>HOWTOs</h3>
<li><a href="howtos.html">Overview</a>
<li><a href="howto-template.html">Templates</a>
<li><a href="tmda-ofmipd.html">tmda-ofmipd</a>
<li><a href="tmda-vdomains.html">Virtual Domains</a>
<h3>Support</h3>
<li><a href="trouble.html">Troubleshooting</a>
<li><a href="http://tmda.net/faq.cgi" TARGET="Resource Window">FAQ</a>
<li><a href="bugs.html">Bugs &amp; Patches</a>
<li><a href="http://tmda.net/lists/listinfo/" TARGET="Resource Window">Mailing Lists</a>
<li><a href="http://mla.libertine.org/" TARGET="Resource Window">List Archive</a> 
<li><a href="support-commercial.html">Commercial Support</a>
<h3>Miscellaneous</h3>
<li><a href="resources.html">External Resources</a>
<li><a href="mirrors.html">Mirrors</a>
<li><a href="logos.html">Logos</a>

==> tmda-1.0.tgz: tmda-1.0/htdocs/links.h <==
<!-- -*- html -*- -->
<h3>About</h3>
<li><a href="index.html">Introduction</a>
<li><a href="history.html">History</a>
<li><a href="features.html">Features</a>
<li><a href="challengeresponse.html">Challenge/Response</a>
<li><a href="results.html">User Testimonials</a>
<li><a href="inuse.html">TMDA In Use</a>
<li><a href="press.html">Press Coverage</a>
<li><a href="donations.html">Donations</a>
<h3>Install</h3>
<li><a href="requirements.html">Requirements</a>
<li><a href="download.html">Download</a>
<li><a href="install.html">Installation</a>
<li><a href="upgrade.html">Upgrading</a>
<h3>Configuration</h3>
<li><a href="config.html">Overview</a>
<li><a href="config-pre.html">Pre-Configuration</a>
<li><a href="config-server.html">Server Configuration</a>
<li><a href="config-client.html">Client Configuration</a>
<li><a href="config-vars.html">Configuration Variables</a>
<li><a href="config-filter.html">Filter Specification</a>
<li><a href="filter-sources.html">Filter Sources</a>
<h3>HOWTOs</h3>
<li><a href="howtos.html">Overview</a>
<li><a href="howto-template.html">Templates</a>
<li><a href="tmda-ofmipd.html">tmda-ofmipd</a>
<li><a href="tmda-vdomains.html">Virtual Domains</a>
<h3>Support</h3>
<li><a href="trouble.html">Troubleshooting</a>
<li><a href="http://tmda.net/faq.cgi" TARGET="Resource Window">FAQ</a>
<li><a href="bugs.html">Bugs &amp; Patches</a>
<li><a href="http://tmda.net/lists/listinfo/" TARGET="Resource Window">Mailing Lists</a>
<li><a href="http://mla.libertine.org/" TARGET="Resource Window">List Archive</a> 
<li><a href="support-commercial.html">Commercial Support</a>
<h3>Miscellaneous</h3>
<li><a href="resources.html">External Resources</a>
<li><a href="mirrors.html">Mirrors</a>
<li><a href="logos.html">Logos</a>
<li><a href="http://www.cafeshops.com/TMDA/" TARGET="Resource Window">Merchandise</a>
